searchData={"content_type":"text/markdown","items":[{"doc":"","ref":"AshRbac.html","title":"AshRbac","type":"module"},{"doc":"Check to determine if the actor has a specific role or if the actor has any of the roles in a list","ref":"AshRbac.HasRole.html","title":"AshRbac.HasRole","type":"module"},{"doc":"","ref":"AshRbac.HasRole.html#strict_check/3","title":"AshRbac.HasRole.strict_check/3","type":"function"},{"doc":"","ref":"AshRbac.HasRole.html#type/0","title":"AshRbac.HasRole.type/0","type":"function"},{"doc":"Introspection functions for the Rbac Extension","ref":"AshRbac.Info.html","title":"AshRbac.Info","type":"module"},{"doc":"","ref":"AshRbac.Info.html#bypass/1","title":"AshRbac.Info.bypass/1","type":"function"},{"doc":"","ref":"AshRbac.Info.html#bypass_roles_field/1","title":"AshRbac.Info.bypass_roles_field/1","type":"function"},{"doc":"","ref":"AshRbac.Info.html#public?/1","title":"AshRbac.Info.public?/1","type":"function"},{"doc":"","ref":"AshRbac.Info.html#roles/1","title":"AshRbac.Info.roles/1","type":"function"},{"doc":"Adds the configured policies to the resource","ref":"AshRbac.Policies.html","title":"AshRbac.Policies","type":"module"},{"doc":"","ref":"AshRbac.Policies.html#after?/1","title":"AshRbac.Policies.after?/1","type":"function"},{"doc":"","ref":"AshRbac.Policies.html#after_compile?/0","title":"AshRbac.Policies.after_compile?/0","type":"function"},{"doc":"","ref":"AshRbac.Policies.html#before?/1","title":"AshRbac.Policies.before?/1","type":"function"},{"doc":"","ref":"AshRbac.Policies.html#transform/1","title":"AshRbac.Policies.transform/1","type":"function"},{"doc":"The Role entity for the DSL of the rbac extension","ref":"AshRbac.Role.html","title":"AshRbac.Role","type":"module"},{"doc":"# Getting Started","ref":"getting_started.html","title":"Getting Started","type":"extras"},{"doc":"Add the ash_rbac dependency to your mix.exs\n\n```elixir\ndefp deps do\n  [\n    {:ash_rbac, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"getting_started.html#installation","title":"Installation - Getting Started","type":"extras"},{"doc":"First, the authorizer and the extension need to be added.\n\n```elixir\ndefmodule RootResource do\n    @moduledoc false\n    use Ash.Resource,\n      data_layer: Ash.DataLayer.Ets,\n      authorizers: [Ash.Policy.Authorizer], # Add the authorizer\n      extensions: [AshRbac] # Add the extension\n  ...\nend\n```\n\nAfterwards, you can add a rbac block to your resource.\n\n```elixir\n  rbac do\n    role :user do\n      fields [:name, :email]\n      actions [:read]\n    end\n  end\n```\n\nThe options defined in the rbac block are transformed into policies during compile time.\n\nThe previous example will generate the following policies:\n\n```elixir\nfield_policies do\n  field_policy [:name, :email]do\n    authorize_if {AshRbac.HasRole, [role: [:user]]}\n  end\n\n  # it also adds a policy for all other fields like this\n  field_policy [:other_fields, ...] do\n    forbid_if always()\n  end\nend\n\npolicies do\n  policy action(:read) do\n    authorize_if {AshRbac.HasRole, [role: [:user]]}\n  end\nend\n```","ref":"getting_started.html#adding-ashrbac-to-your-resource","title":"Adding AshRbac to your resource - Getting Started","type":"extras"},{"doc":"# Relationships\n\nAs relationships are not part of field policies it is necessary to protect them with an action policy.\nThis can be done by passing a custom condition to the action.\n\n```elixir\n# only allow read access if accessed from a parent\nrbac do\n  role :user do\n    actions [\n      {:read, accessing_from(Parent, :child)}\n    ]\n  end\nend\n\n# result\npolicies do\n  policy [action(:read), accessing_from(Parent, :child)] do\n    authorize_if {AshRbac.HasRole, [role: :user]}\n  end\nend\n```","ref":"relationships.html","title":"Relationships","type":"extras"},{"doc":"# AshRbac\n\nA small extension that allows for easier application of policies\n\n```elixir\nrbac do\n  role :user do\n    fields [:fields, :user, :can, :see]\n    actions [:actions, :user, :can :use]\n  end\nend\n```","ref":"readme.html","title":"Readme","type":"extras"},{"doc":"The package can be installed by adding `ash_rbac` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ash_rbac, \"~> 0.3.0\"},\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - Readme","type":"extras"}]}